==> Banners-2.3.7.tar.gz: Banners/lang/ext/nl_NL.php <==
<?php
$lang['help_param_action'] = 'Specificeert het handelen van de module. Mogelijke waarden zijn &quot;default&quot; en &quot;list&quot;. De standaard actie wordt gebruikt voor het tonen van een enkele banner volgens het gespecificeerde criterium. De lijst actie wordt gebruikt om alle banners te tonen van een gespecificeerde categorie of categorie id';
$lang['help_param_category'] = 'In de standaard actie, wordt deze parameter gebruikt om de naam van de categorie te specificeren vanwaar een enkele banner wordt getoond.  In de lijst categorie is deze parameter verplicht om de naam van de categorie te specificeren vanwaar alle banners worden getoond';
$lang['help_param_mode'] = 'Deze parameter wordt alleen gebruikt in de standaard actie, het specificeert de manier hoe banners worden geselecteerd uit de gespecificeerde categorie.  De enige waarde is &quot;sequential&quot; welke bepaald hoe de module een keus maakt uit de volgende niet verlopen  banner met de laagste aantal vertoningen.  Deze parameter niet specificeren resulteert in een willekeurige vertoning.';
$lang['help_param_name'] = 'Deze parameter wordt alleen gebruikt in de standaard actie.  Het specificeert een absolute naam van een te laden banner.  Maar, als de banner verkeerd is (het aantal vertoningen is bereikt, OF is verlopen), dan wordt er niets getoond.';
$lang['bannerlist_template'] = 'Banner Lijst Sjabloon';
$lang['info_bannerlist_template'] = 'Gebruikt met de lijst actie, dit sjabloon controleert het tonen van alle banners in de geselecteerde categorie';
$lang['none'] = 'Geen';
$lang['error_invalid_dates'] = 'Fout Verkeerde Data';
$lang['editbanner'] = 'Wijzig Banner';
$lang['start_date'] = 'Startdatum';
$lang['atttext'] = 'op';
$lang['template'] = 'Sjabloon';
$lang['default_template'] = 'Standaard Categorie Sjabloon';
$lang['reset_template'] = 'Reset Sjabloon naar de standaard versie';
$lang['error_banners'] = 'Geen banners';
$lang['error_bannerexists'] = 'Er bestaat al een banner met deze naam';
$lang['accessdenied'] = 'Toegang geweigerd. Controleer uw rechten.';
$lang['addbanner'] = 'Voeg banner toe';
$lang['addcategory'] = 'Voeg categorie toe';
$lang['areyousure'] = 'Weet u het zeker?';
$lang['banners'] = 'Banners ';
$lang['cancel'] = 'Annuleer';
$lang['categories'] = 'Categorie&euml;n';
$lang['category'] = 'Categorie';
$lang['created'] = 'Gemaakt';
$lang['date'] = 'Datum';
$lang['delete'] = 'Verwijder';
$lang['description'] = 'Beschrijving';
$lang['edit'] = 'Bewerk';
$lang['editcategory'] = 'Bewerk categorie';
$lang['error'] = 'Fout!';
$lang['error_banerexists'] = 'Er bestaat al een banner met die naam';
$lang['error_categorynotempty'] = 'Fout: Categorie is niet leeg!';
$lang['error_dberror'] = 'Fout in database!';
$lang['error_emptybannername'] = 'Fout: Geen banner naam!';
$lang['error_emptycategory'] = 'Fout: Geen categorie!';
$lang['error_insufficientparams'] = 'Fout: Onvoldoende invoer';
$lang['error_nocategories'] = 'Fout: Geen categorie&euml;n gevonden';
$lang['error_noresults'] = 'Er zijn geen banners die overeenkomen met deze query';
$lang['error_textorimage'] = 'Geef een url en een afbeelding of  tekst, niet allebei!';
$lang['expires'] = 'Loopt af op';
$lang['friendlyname'] = 'Banners beheren';
$lang['height'] = 'Hoogte';
$lang['hits'] = 'Hits  ';
$lang['href_text'] = 'Link-tekst';
$lang['id'] = 'ID ';
$lang['image'] = 'Afbeelding';
$lang['image_text'] = 'Alternatieve afbeeldingstekst';
$lang['impressions'] = 'Aantal keer bekeken';
$lang['info_href_text'] = 'Aanvullende tekst voor de linktag. Deze tekst wordt in de link-tag geplaatst.';
$lang['info_image'] = 'Geef een bestand ten opzichte van uw uploads-map';
$lang['info_image_text'] = 'Aanvullende tekst voor de afbeeldings-tag';
$lang['info_max_hits'] = 'Kies 0 voor ongelimiteerde hits';
$lang['info_max_impressions'] = 'Kies 0 voor ongelimiteerd aantal keer bekeken';
$lang['installed'] = 'Moduleversie %s ge&iuml;nstalleerd.';
$lang['ipaddress'] = 'IP-adres';
$lang['max_hits'] = 'Maximum hits';
$lang['max_impressions'] = 'Maximum aantal keer bekeken';
$lang['name'] = 'Naam';
$lang['never'] = 'Nooit';
$lang['postinstall'] = 'Installatie gereed. Vergeet niet het &quot;Manage Banners&quot; recht in te stellen!';
$lang['postuninstall'] = 'Banners-module gede&iuml;nstalleerd en alle database-tabellen verwijderd.&quot;';
$lang['preferences'] = 'Voorkeuren';
$lang['prefsupdated'] = 'Modulevoorkeuren bijgewerkt.';
$lang['prompt_categorydesc'] = 'Categorieomschrijving';
$lang['prompt_categoryname'] = 'Categorienaam';
$lang['prompt_imageheight'] = 'Afbeeldingshoogte';
$lang['prompt_imagewidth'] = 'Afbeeldingsbreedte';
$lang['prompt_subnet_exclusions'] = 'Sluit deze subnetten uit van de statistieken';
$lang['prompt_upload_category'] = 'Categorie (Uploads-module)';
$lang['prompt_upload_file'] = 'Afbeelding (Uploads-module)';
$lang['selectcategory'] = 'Selecteer categorie';
$lang['submit'] = 'Verstuur';
$lang['text'] = 'Tekst';
$lang['title_mod_admin'] = 'Modulebeheerpaneel';
$lang['title_mod_prefs'] = 'Modulevoorkeuren';
$lang['uninstalled'] = 'Module verwijderd.';
$lang['upgraded'] = 'Module bijgewerkt naar versie %s.';
$lang['url'] = 'URL ';
$lang['width'] = 'Breedte';
$lang['title_admin_panel'] = 'Banners-module';
$lang['moddescription'] = 'Een module om banners af te wisselen';
$lang['welcome_text'] = '<p>Welkom bij de Banner beheermodule.</p>';
$lang['changelog'] = '<ul>
<li>Version 1.0. 6 August 2005. Initial Release.</li>
<li>Version 2.0. September 2005. Initial Release for 0.1..</li>
<li>Version 2.0.1. September 2005. Display sample banner in the edit banner page, added name= parameter, and made subnet exclusions work.  Also changed the definition of the database to allow for additional text in the link and image tags.</li>
<li>Version 2.0.2. September 2005. Added integration with the uploads module (1.0.6) so that we can get lits of files for banners, etc.  The banners module is still optional though.</li>
<li>Version 2.0.3. September 2005. Fixed a very minor issue with never expires..</li>
<li>Version 2.0.4. September 2005. Fixed a very minor issue with module dependencies, and a big bug in the database spec if you did a scratch install.</li>
<li>Version 2.0.5. October 2005. Add coments around the output</li>
<li>Version 2.0.6. December 2005. Minor validation fixes, description is now output between the <img>and</img> tags, and an alt attribute is in the img tag.</li>
<li>Version 2.0.7. January 2006. More validation fixes, Moved the admin tabs around, fixed an issue where you could almost create a banner without defining a category, and... fixed the expiry date issue for good (hopefully).</li>
<li>Version 2.1.0. August 2006. Prepared for 1.0 compatibility, split into multiple files, used references where possible, improved messages, and a general cleanup.</li>
<li>Version 2.2. March 2008. 
    <p>The first release in a long while this fixes issues with the date fields, and the expiry date.  Also integrates changes so that the active tab is maintaned (DeeEye) and changes the license.</p>
    <p>Now require CMS 1.2.3 or greater</p>
</li>
<li>Version 2.2.1. April 2008.
    <p>Minor fixes.</p>
</li>
<li>Version 2.2.3. April 2009.
    <p>Remove the width and height parameters, add a start date, and now use templates... major overhaul.</p>
</li>
<li>Version 2.3 - September 2009.
  <ul>
    <li>Major cleanup of code</li>
    <li>Get rid of the never expire stuff... people can just use a really long date.</li>
    <li>Dont ask for input of times any more... just use days</li>
    <li>Fixed to work with newest version of uploads, if it can be found.</li>
    <li>Now depends on CGExtensions</li>
    <li>Adds the banner list action.</li>
  </ul>
</li>
</ul>';
$lang['help'] = '<h3>Wat doet het?</h3>
<p>Deze module beheert vele banner-categorie&euml;n, registreert hits en het aantal vertoningen en de verloopdatum en selecteert uit alle beschikbare en geldige banners er een om te tonen.</p>
<h3>Hoe gebruikt u het</h3>
<p>Om deze module te gebruiken plaatst u de module-code in een pagina of sjabloon met behulp van de smarty tag {cms_module module=&#039;Banners&#039; category=&quot;<categorie>&quot;}</p> 
<p>U moet ook de banners uploaden naar een geschikte map binnen de Uploads-map. Via het beheerpaneel kunt u banners toevoegen aan de database.</p
<h3>Parameters</h3>
<ul>
<li><em>(verplicht)</em> category=&quot;categorie&quot; = selecteert willekeurig uit alle beschikbare banners in deze categorie</li>
<li><em>(optioneel)</em> name=&quot;naam&quot; = selecteert alleen de banner met deze naam</li>
</ul>
<h4>Tip</h4>
<p>De Uploads-module en de Banners-module werken goed samen. U kunt de &quot;banners&quot; categorie in de Uploads-module aanmaken en uw banner-afbeeldingen hier naartoe uploaden. Vervolgens specificeert u &quot;banners/<bestandsnaam>&quot; bij het toevoegen van een banner in de Banners-module.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
module homepage at <a href="http://techcom.dyndns.org">techcom.dyndns.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['utma'] = '156861353.1764090269059867100.1239886062.1251979126.1251997198.77';
$lang['utmz'] = '156861353.1251892206.73.12.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['qca'] = '4824ac14-af799-a4257-f4cde';
$lang['utmb'] = '156861353.8.10.1251997198';
$lang['utmc'] = '156861353';
?>

==> Banners-2.5.3.tar.gz: Banners/lang/ext/nl_NL.php <==
<?php
$lang['statreport_linesperpage'] = 'Regels per pagina in een Statistiek Rapportage';
$lang['banner'] = 'Banner advertenties';
$lang['of'] = 'Van';
$lang['page'] = 'Pagina';
$lang['generated'] = 'Gegenereerd';
$lang['generated_by'] = 'Gegenereerd door';
$lang['desc_stats_report'] = 'Een rapport dat het aantal weergaven en kliks weergeeft van de Banner Module';
$lang['title_stats_report'] = 'Banner statistiekenraport';
$lang['view_statistics'] = 'Geef statistieken weer';
$lang['msg_new_window'] = 'Cre&euml;er een nieuw venster';
$lang['statreport_template'] = 'Statistiekenreport sjabloon';
$lang['your_ad_here'] = 'Hier had uw advertentie kunnen staan';
$lang['prompt_dflt_image'] = 'Standaard afbeelding';
$lang['prompt_dflt_url'] = 'Standaard url';
$lang['info_dflt_image'] = 'Stel een standaard afbeelding in die wordt getoond als er geen (correcte) afbeelding is ingesteld.';
$lang['prompt_hidefrombots'] = 'Tel zoekmachinerobot bezoeken niet mee met de advertentie vertoningen';
$lang['help_param_action'] = 'Specificeert het handelen van de module. Mogelijke waarden zijn &quot;default&quot; en &quot;list&quot;. De standaard actie wordt gebruikt voor het tonen van een enkele banner volgens het gespecificeerde criterium. De lijst actie wordt gebruikt om alle banners te tonen van een gespecificeerde categorie of categorie id';
$lang['help_param_category'] = 'In de standaard actie, wordt deze parameter gebruikt om de naam van de categorie te specificeren vanwaar een enkele banner wordt getoond.  In de lijst categorie is deze parameter verplicht om de naam van de categorie te specificeren vanwaar alle banners worden getoond';
$lang['help_param_mode'] = 'Deze parameter wordt alleen gebruikt in de standaard actie, het specificeert de manier hoe banners worden geselecteerd uit de gespecificeerde categorie.  De enige waarde is &quot;sequential&quot; welke bepaald hoe de module een keus maakt uit de volgende niet verlopen  banner met de laagste aantal vertoningen.  Deze parameter niet specificeren resulteert in een willekeurige vertoning.';
$lang['help_param_name'] = 'Deze parameter wordt alleen gebruikt in de standaard actie.  Het specificeert een absolute naam van een te laden banner.  Maar, als de banner verkeerd is (het aantal vertoningen is bereikt, OF is verlopen), dan wordt er niets getoond.';
$lang['bannerlist_template'] = 'Banner Lijst Sjabloon';
$lang['info_bannerlist_template'] = 'Gebruikt met de lijst actie, dit sjabloon controleert het tonen van alle banners in de geselecteerde categorie';
$lang['none'] = 'Geen';
$lang['error_invalid_dates'] = 'Fout, verkeerde data';
$lang['editbanner'] = 'Wijzig Banner';
$lang['start_date'] = 'Startdatum';
$lang['atttext'] = 'op';
$lang['template'] = 'Sjabloon';
$lang['default_template'] = 'Standaard Categorie Sjabloon';
$lang['reset_template'] = 'Reset Sjabloon naar de standaard versie';
$lang['error_banners'] = 'Geen banners';
$lang['error_bannerexists'] = 'Er bestaat al een banner met deze naam';
$lang['accessdenied'] = 'Toegang geweigerd. Controleer uw rechten.';
$lang['addbanner'] = 'Voeg banner toe';
$lang['addcategory'] = 'Voeg categorie toe';
$lang['areyousure'] = 'Weet u het zeker?';
$lang['banners'] = 'Banners ';
$lang['cancel'] = 'Annuleer';
$lang['categories'] = 'Categorie&euml;n';
$lang['category'] = 'Categorie';
$lang['created'] = 'Gemaakt';
$lang['date'] = 'Datum';
$lang['delete'] = 'Verwijder';
$lang['description'] = 'Beschrijving';
$lang['edit'] = 'Bewerk';
$lang['editcategory'] = 'Bewerk categorie';
$lang['error'] = 'Fout!';
$lang['error_banerexists'] = 'Er bestaat al een banner met die naam';
$lang['error_categorynotempty'] = 'Fout: Categorie is niet leeg!';
$lang['error_dberror'] = 'Fout: Database probleem!';
$lang['error_emptybannername'] = 'Fout: Geen banner naam!';
$lang['error_emptycategory'] = 'Fout: Geen categorie!';
$lang['error_insufficientparams'] = 'Fout: Onvoldoende invoer';
$lang['error_nocategories'] = 'Fout: Geen categorie&euml;n gevonden';
$lang['error_noresults'] = 'Er zijn geen banners die overeenkomen met deze query';
$lang['error_textorimage'] = 'Geef een url en een afbeelding of  tekst, niet allebei!';
$lang['expires'] = 'Loopt af op';
$lang['friendlyname'] = 'Banners beheren';
$lang['height'] = 'Hoogte';
$lang['hits'] = 'Hits  ';
$lang['href_text'] = 'Link-tekst';
$lang['id'] = 'ID ';
$lang['image'] = 'Afbeelding';
$lang['image_text'] = 'Alternatieve afbeeldingstekst';
$lang['impressions'] = 'Aantal keer bekeken';
$lang['info_href_text'] = 'Aanvullende tekst voor de linktag. Deze tekst wordt in de link-tag geplaatst.';
$lang['info_image'] = 'Geef een bestand ten opzichte van uw uploads-map';
$lang['info_image_text'] = 'Aanvullende tekst voor de afbeeldings-tag';
$lang['info_max_hits'] = 'Kies 0 voor ongelimiteerde hits';
$lang['info_max_impressions'] = 'Kies 0 voor ongelimiteerd aantal keer bekeken';
$lang['installed'] = 'Moduleversie %s ge&iuml;nstalleerd.';
$lang['ipaddress'] = 'IP-adres';
$lang['max_hits'] = 'Maximum hits';
$lang['max_impressions'] = 'Maximum aantal keer bekeken';
$lang['name'] = 'Naam';
$lang['never'] = 'Nooit';
$lang['postinstall'] = 'Installatie gereed. Vergeet niet het &quot;Manage Banners&quot; recht in te stellen!';
$lang['postuninstall'] = 'Banners-module gede&iuml;nstalleerd en alle database-tabellen verwijderd.';
$lang['preferences'] = 'Voorkeuren';
$lang['prefsupdated'] = 'Modulevoorkeuren bijgewerkt.';
$lang['prompt_categorydesc'] = 'Categorieomschrijving';
$lang['prompt_categoryname'] = 'Categorienaam';
$lang['prompt_imageheight'] = 'Afbeeldingshoogte';
$lang['prompt_imagewidth'] = 'Afbeeldingsbreedte';
$lang['prompt_subnet_exclusions'] = 'Sluit deze subnetten uit van de statistieken';
$lang['prompt_upload_category'] = 'Categorie (Uploads-module)';
$lang['prompt_upload_file'] = 'Afbeelding (Uploads-module)';
$lang['selectcategory'] = 'Selecteer categorie';
$lang['submit'] = 'Verstuur';
$lang['text'] = 'Tekst';
$lang['title_mod_admin'] = 'Modulebeheerpaneel';
$lang['title_mod_prefs'] = 'Modulevoorkeuren';
$lang['uninstalled'] = 'Module verwijderd.';
$lang['upgraded'] = 'Module bijgewerkt naar versie %s.';
$lang['url'] = 'URL ';
$lang['width'] = 'Breedte';
$lang['title_admin_panel'] = 'Banners-module';
$lang['moddescription'] = 'Een module om wisselende banners op de website te tonen';
$lang['welcome_text'] = '<p>Welkom op de Banner module beheerpagina.</p>';
$lang['help'] = '<h3>Wat doet het?</h3>
<p>Deze module beheerd vele banner-categorie&euml;n, registreert hits en het aantal vertoningen en de verloopdatum en selecteert uit alle beschikbare en geldige banners er een om te tonen.</p>
<h3>Hoe gebruikt u het</h3>
<p>Om deze module te gebruiken plaatst u de module-code in een pagina of sjabloon met behulp van de smarty tag {cms_module module=&#039;Banners&#039; category=&quot;<categorie>&quot;}</p> 
<p>U moet ook de banners uploaden naar een geschikte map binnen de Uploads-map. Via het beheerpaneel kunt u banners toevoegen aan de database.</p
<h3>Parameters</h3>
<ul>
<li><em>(verplicht)</em> category=&quot;categorie&quot; = selecteert willekeurig uit alle beschikbare banners in deze categorie</li>
<li><em>(optioneel)</em> name=&quot;naam&quot; = selecteert alleen de banner met deze naam</li>
</ul>
<h4>Tip</h4>
<p>De Uploads-module en de Banners-module werken goed samen. U kunt de &quot;banners&quot; categorie in de Uploads-module aanmaken en uw banner-afbeeldingen hier naartoe uploaden. Vervolgens specificeert u &quot;banners/<bestandsnaam>&quot; bij het toevoegen van een banner in de Banners-module.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
module homepage at <a href="http://techcom.dyndns.org">techcom.dyndns.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['utma'] = '156861353.309482405.1295986369.1300304438.1300383712.85';
$lang['utmz'] = '156861353.1300304438.84.25.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/viewtopic.php';
$lang['qca'] = 'P0-1346119953-1295986368908';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
